#[repr(u8)]pub enum Dir {
Positive = 0,
Negative = 1,
}Expand description
Abstract concept of direction of movement, whether linear or rotational.
Used in TrackPos to determine whether a train is moving towards the “start” or the “end” node of the segment.
Variants
Implementations